-- =============================================
-- SaveToDB Framework for MySQL
-- Version 7.19, March 12, 2018
--
-- Copyright 2013-2018 Gartle Technology Corporation
-- =============================================

CREATE SCHEMA IF NOT EXISTS savetodb_dev DEFAULT CHARACTER SET utf8 DEFAULT COLLATE utf8_general_ci;
CREATE SCHEMA IF NOT EXISTS savetodb_xls DEFAULT CHARACTER SET utf8 DEFAULT COLLATE utf8_general_ci;

-- print Schemas have been created

CREATE TABLE IF NOT EXISTS savetodb_dev.query_list (
    ID INTEGER NOT NULL AUTO_INCREMENT,
    TABLE_SCHEMA VARCHAR(64) NOT NULL,
    TABLE_NAME VARCHAR(64) NOT NULL,
    TABLE_TYPE VARCHAR(64) NOT NULL,
    TABLE_CODE MEDIUMTEXT,
    INSERT_PROCEDURE MEDIUMTEXT,
    UPDATE_PROCEDURE MEDIUMTEXT,
    DELETE_PROCEDURE MEDIUMTEXT,
    PROCEDURE_TYPE VARCHAR(64),
    PRIMARY KEY (ID)
);

CREATE OR REPLACE VIEW savetodb_dev.view_query_list
AS
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , NULL AS TABLE_CODE
    , COALESCE(q.INSERT_PROCEDURE, CONCAT(i.ROUTINE_SCHEMA, '.', i.ROUTINE_NAME)) AS INSERT_PROCEDURE
    , COALESCE(q.UPDATE_PROCEDURE, CONCAT(u.ROUTINE_SCHEMA, '.', u.ROUTINE_NAME)) AS UPDATE_PROCEDURE
    , COALESCE(q.DELETE_PROCEDURE, CONCAT(d.ROUTINE_SCHEMA, '.', d.ROUTINE_NAME)) AS DELETE_PROCEDURE
    , COALESCE(q.PROCEDURE_TYPE, CASE WHEN i.ROUTINE_NAME IS NOT NULL THEN 'PROCEDURE' ELSE NULL END) AS PROCEDURE_TYPE
FROM
    information_schema.tables t
    LEFT OUTER JOIN information_schema.routines i ON i.ROUTINE_SCHEMA = t.TABLE_SCHEMA AND i.ROUTINE_NAME = CONCAT(REPLACE(t.TABLE_NAME, '_select', ''), '_insert')
    LEFT OUTER JOIN information_schema.routines u ON u.ROUTINE_SCHEMA = t.TABLE_SCHEMA AND u.ROUTINE_NAME = CONCAT(REPLACE(t.TABLE_NAME, '_select', ''), '_update')
    LEFT OUTER JOIN information_schema.routines d ON d.ROUTINE_SCHEMA = t.TABLE_SCHEMA AND d.ROUTINE_NAME = CONCAT(REPLACE(t.TABLE_NAME, '_select', ''), '_delete')
    LEFT OUTER JOIN savetodb_dev.query_list q ON q.TABLE_SCHEMA = t.TABLE_SCHEMA AND q.TABLE_NAME = t.TABLE_NAME
WHERE
    NOT t.TABLE_SCHEMA IN ('information_schema', 'mysql', 'performance_schema')
UNION
SELECT
    r.ROUTINE_SCHEMA AS TABLE_SCHEMA
    , r.ROUTINE_NAME AS TABLE_NAME
    , r.ROUTINE_TYPE AS TABLE_TYPE
    , NULL AS TABLE_CODE
    , COALESCE(q.INSERT_PROCEDURE, CONCAT(i.ROUTINE_SCHEMA, '.', i.ROUTINE_NAME)) AS INSERT_PROCEDURE
    , COALESCE(q.UPDATE_PROCEDURE, CONCAT(u.ROUTINE_SCHEMA, '.', u.ROUTINE_NAME)) AS UPDATE_PROCEDURE
    , COALESCE(q.DELETE_PROCEDURE, CONCAT(d.ROUTINE_SCHEMA, '.', d.ROUTINE_NAME)) AS DELETE_PROCEDURE
    , COALESCE(q.PROCEDURE_TYPE, CASE WHEN i.ROUTINE_NAME IS NOT NULL THEN 'PROCEDURE' ELSE NULL END) AS PROCEDURE_TYPE
FROM 
    information_schema.routines r
    LEFT OUTER JOIN information_schema.routines i ON i.ROUTINE_SCHEMA = r.ROUTINE_SCHEMA AND i.ROUTINE_NAME = CONCAT(REPLACE(r.ROUTINE_NAME, '_select', ''), '_insert')
    LEFT OUTER JOIN information_schema.routines u ON u.ROUTINE_SCHEMA = r.ROUTINE_SCHEMA AND u.ROUTINE_NAME = CONCAT(REPLACE(r.ROUTINE_NAME, '_select', ''), '_update')
    LEFT OUTER JOIN information_schema.routines d ON d.ROUTINE_SCHEMA = r.ROUTINE_SCHEMA AND d.ROUTINE_NAME = CONCAT(REPLACE(r.ROUTINE_NAME, '_select', ''), '_delete')
    LEFT OUTER JOIN savetodb_dev.query_list q ON q.TABLE_SCHEMA = r.ROUTINE_SCHEMA AND q.TABLE_NAME = r.ROUTINE_NAME
WHERE
    NOT r.ROUTINE_SCHEMA IN ('information_schema', 'mysql', 'performance_schema')
    AND r.ROUTINE_TYPE = 'PROCEDURE'
    AND NOT (
        r.ROUTINE_NAME LIKE '%_insert'
        OR r.ROUTINE_NAME LIKE '%_update'
        OR r.ROUTINE_NAME LIKE '%_delete'
        OR r.ROUTINE_NAME LIKE '%_merge'
        OR r.ROUTINE_NAME LIKE '%_change'
    )
UNION
SELECT
    q.TABLE_SCHEMA
    , q.TABLE_NAME
    , q.TABLE_TYPE
    , q.TABLE_CODE
    , q.INSERT_PROCEDURE
    , q.UPDATE_PROCEDURE
    , q.DELETE_PROCEDURE
    , q.PROCEDURE_TYPE
FROM
    savetodb_dev.query_list q
    LEFT OUTER JOIN information_schema.tables t ON q.TABLE_SCHEMA = t.TABLE_SCHEMA AND q.TABLE_NAME = t.TABLE_NAME
    LEFT OUTER JOIN information_schema.routines r ON q.TABLE_SCHEMA = r.ROUTINE_SCHEMA AND q.TABLE_NAME = r.ROUTINE_NAME
WHERE
    q.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND t.TABLE_NAME IS NULL
    AND r.ROUTINE_NAME IS NULL
ORDER BY
    TABLE_SCHEMA
    , TABLE_NAME;

CREATE OR REPLACE VIEW savetodb_xls.view_query_list
AS
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , t.TABLE_CODE
    , t.INSERT_PROCEDURE
    , t.UPDATE_PROCEDURE
    , t.DELETE_PROCEDURE
    , t.PROCEDURE_TYPE
FROM
    savetodb_dev.view_query_list t
WHERE
    NOT t.TABLE_SCHEMA IN ('savetodb_dev')
    AND NOT t.TABLE_NAME IN (
        'view_column_translation'
        , 'view_object_translation'
        , 'view_event_handlers'
        , 'view_table_formats'
        , 'view_parameter_values'
        , 'view_query_list'
        )
    AND NOT t.TABLE_NAME LIKE 'xl_%'
ORDER BY
    TABLE_SCHEMA
    , TABLE_NAME;

-- print QueryList objects have been created

CREATE TABLE IF NOT EXISTS savetodb_dev.object_translation (
    ID INTEGER NOT NULL NOT NULL AUTO_INCREMENT,
    TABLE_SCHEMA VARCHAR(64) NOT NULL,
    TABLE_NAME VARCHAR(64) NOT NULL,
    LANGUAGE_NAME CHARACTER(2) NOT NULL,
    TRANSLATED_NAME VARCHAR(64),
    TRANSLATED_DESC VARCHAR(256),
    TRANSLATED_COMMENT VARCHAR(2000),
    PRIMARY KEY (ID)
);

ALTER TABLE savetodb_dev.object_translation
    ADD UNIQUE INDEX ix_schema_name_language
    USING BTREE (
        TABLE_SCHEMA,
        TABLE_NAME,
        LANGUAGE_NAME
    );

CREATE TABLE IF NOT EXISTS savetodb_dev.column_translation (
    ID INTEGER NOT NULL AUTO_INCREMENT,
    TABLE_SCHEMA VARCHAR(64),
    TABLE_NAME VARCHAR(64),
    COLUMN_NAME VARCHAR(64) NOT NULL,
    LANGUAGE_NAME CHARACTER(2) NOT NULL,
    TRANSLATED_NAME VARCHAR(64),
    TRANSLATED_DESC VARCHAR(1024),
    PRIMARY KEY (ID)
);

ALTER TABLE savetodb_dev.column_translation
    ADD UNIQUE INDEX ix_schema_name_column_language
    USING BTREE (
        TABLE_SCHEMA,
        TABLE_NAME,
        COLUMN_NAME,
        LANGUAGE_NAME
    );
    
CREATE VIEW savetodb_xls.view_object_translation
AS
SELECT
    t.ID,
    t.TABLE_SCHEMA,
    t.TABLE_NAME,
    t.LANGUAGE_NAME,
    t.TRANSLATED_NAME,
    t.TRANSLATED_DESC,
    t.TRANSLATED_COMMENT
FROM
    savetodb_dev.object_translation t
;

CREATE VIEW savetodb_xls.view_column_translation
AS
SELECT
    t.ID,
    t.TABLE_SCHEMA,
    t.TABLE_NAME,
    t.COLUMN_NAME,
    t.LANGUAGE_NAME,
    t.TRANSLATED_NAME,
    t.TRANSLATED_DESC
FROM
    savetodb_dev.column_translation t
;

CREATE VIEW savetodb_xls.view_object_description
AS
SELECT
    t.ID
    , t.LANGUAGE_NAME
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TRANSLATED_NAME
    , t.TRANSLATED_COMMENT
FROM
    savetodb_dev.object_translation t
WHERE
    t.TRANSLATED_NAME IS NOT NULL
    AND t.TRANSLATED_COMMENT IS NOT NULL
    AND NOT t.TABLE_SCHEMA IN ('information_schema', 'mysql', 'savetodb_dev', 'savetodb_xls')
    AND NOT t.TABLE_NAME LIKE '%_insert'
    AND NOT t.TABLE_NAME LIKE '%_update'
    AND NOT t.TABLE_NAME LIKE '%_delete'
    AND NOT t.TABLE_NAME LIKE '%_merge'
    AND NOT t.TABLE_NAME LIKE 'xl_%'
;

-- print Translation objects have been created

CREATE TABLE IF NOT EXISTS savetodb_dev.event_handlers (
    ID INTEGER NOT NULL AUTO_INCREMENT,
    TABLE_SCHEMA VARCHAR(64) NOT NULL,
    TABLE_NAME VARCHAR(64) NOT NULL,
    COLUMN_NAME VARCHAR(64),
    EVENT_NAME VARCHAR(50) NOT NULL,
    HANDLER_SCHEMA VARCHAR(64),
    HANDLER_NAME VARCHAR(64),
    HANDLER_TYPE VARCHAR(64),
    HANDLER_CODE MEDIUMTEXT,
    TARGET_WORKSHEET VARCHAR(256),
    MENU_ORDER SMALLINT,
    EDIT_PARAMETERS BIT(1),
    PRIMARY KEY (ID)
);

CREATE OR REPLACE VIEW savetodb_xls.view_event_handlers
AS
SELECT
    t.ID,
    t.TABLE_SCHEMA,
    t.TABLE_NAME,
    t.COLUMN_NAME,
    t.EVENT_NAME,
    t.HANDLER_SCHEMA,
    t.HANDLER_NAME,
    t.HANDLER_TYPE,
    t.HANDLER_CODE,
    t.TARGET_WORKSHEET,
    t.MENU_ORDER,
    t.EDIT_PARAMETERS
FROM
    savetodb_dev.event_handlers t
;

-- print EventHandlers objects have been created

CREATE TABLE IF NOT EXISTS savetodb_dev.parameter_values
(
    ID INTEGER NOT NULL AUTO_INCREMENT,
    TABLE_SCHEMA VARCHAR(64) NOT NULL,
    TABLE_NAME VARCHAR(64) NOT NULL,
    PARAMETER_NAME VARCHAR(64) NOT NULL,
    SELECT_SCHEMA VARCHAR(64),
    SELECT_NAME VARCHAR(64) NOT NULL,
    SELECT_TYPE VARCHAR(64),
    SELECT_CODE MEDIUMTEXT,
    PRIMARY KEY (ID)
);

ALTER TABLE savetodb_dev.parameter_values
    ADD UNIQUE INDEX ix_schema_name_parameter
    USING BTREE (
        TABLE_SCHEMA,
        TABLE_NAME,
        PARAMETER_NAME
    );
    
CREATE OR REPLACE VIEW savetodb_xls.view_parameter_values
AS
SELECT 
    t.ID,
    t.TABLE_SCHEMA,
    t.TABLE_NAME,
    t.PARAMETER_NAME,
    t.SELECT_SCHEMA,
    t.SELECT_NAME,
    t.SELECT_TYPE,
    t.SELECT_CODE
FROM 
    savetodb_dev.parameter_values t
;

-- print ParameterValues  objects have been created

CREATE TABLE IF NOT EXISTS savetodb_dev.table_formats (
    ID INTEGER NOT NULL AUTO_INCREMENT,
    TABLE_SCHEMA VARCHAR(64) NOT NULL,
    TABLE_NAME VARCHAR(64) NOT NULL,
    TABLE_EXCEL_FORMAT_XML MEDIUMTEXT,
    PRIMARY KEY (ID)
);

ALTER TABLE savetodb_dev.table_formats
    ADD UNIQUE INDEX ix_table_formats_schema_name
    USING BTREE (
        TABLE_SCHEMA, 
        TABLE_NAME
    );
    
CREATE OR REPLACE VIEW savetodb_xls.view_table_formats
AS
SELECT
    t.ID,
    t.TABLE_SCHEMA,
    t.TABLE_NAME,
    t.TABLE_EXCEL_FORMAT_XML
FROM
    savetodb_dev.table_formats t
;

DELIMITER //
CREATE PROCEDURE savetodb_dev.table_format_save (
        IN `Schema` VARCHAR(64),
        IN `Name` VARCHAR(64),
        IN `ExcelFormatXML` MEDIUMTEXT
    )
    NOT DETERMINISTIC
    MODIFIES SQL DATA
    SQL SECURITY DEFINER
    COMMENT ''
BEGIN
DECLARE RowCount INTEGER;

IF `Schema` IS NOT NULL AND `Name` IS NOT NULL THEN
    IF ExcelFormatXML IS NULL THEN
        DELETE FROM savetodb_dev.table_formats
        WHERE
            TABLE_SCHEMA = `Schema` AND TABLE_NAME = `Name`;
    ELSE
        SELECT COUNT(*) INTO RowCount
        FROM savetodb_dev.table_formats
        WHERE
            TABLE_SCHEMA = `Schema` AND TABLE_NAME = `Name`;

        IF (RowCount = 0) THEN
            INSERT INTO savetodb_dev.table_formats
                (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML)
            VALUES
                (`Schema`, `Name`, ExcelFormatXML);
        ELSE
            UPDATE savetodb_dev.table_formats
            SET
                TABLE_SCHEMA = `Schema`,
                TABLE_NAME = `Name`,
                TABLE_EXCEL_FORMAT_XML = ExcelFormatXML
            WHERE
                TABLE_SCHEMA = `Schema` AND TABLE_NAME = `Name`;
        END IF;
    END IF;
END IF;
END //
DELIMITER ;

-- print TableFormats objects have been created

insert into `savetodb_dev`.`query_list` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_TYPE`, `TABLE_CODE`, `INSERT_PROCEDURE`, `UPDATE_PROCEDURE`, `DELETE_PROCEDURE`, `PROCEDURE_TYPE`) values ('savetodb_xls', 'view_table_formats',      'VIEW', NULL, 'savetodb_dev.table_formats', 'savetodb_dev.table_formats', 'savetodb_dev.table_formats', 'TABLE');
insert into `savetodb_dev`.`query_list` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_TYPE`, `TABLE_CODE`, `INSERT_PROCEDURE`, `UPDATE_PROCEDURE`, `DELETE_PROCEDURE`, `PROCEDURE_TYPE`) values ('savetodb_xls', 'view_parameter_values',   'VIEW', NULL, 'savetodb_dev.parameter_values', 'savetodb_dev.parameter_values', 'savetodb_dev.parameter_values', 'TABLE');
insert into `savetodb_dev`.`query_list` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_TYPE`, `TABLE_CODE`, `INSERT_PROCEDURE`, `UPDATE_PROCEDURE`, `DELETE_PROCEDURE`, `PROCEDURE_TYPE`) values ('savetodb_xls', 'view_event_handlers',     'VIEW', NULL, 'savetodb_dev.event_handlers', 'savetodb_dev.event_handlers', 'savetodb_dev.event_handlers', 'TABLE');
insert into `savetodb_dev`.`query_list` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_TYPE`, `TABLE_CODE`, `INSERT_PROCEDURE`, `UPDATE_PROCEDURE`, `DELETE_PROCEDURE`, `PROCEDURE_TYPE`) values ('savetodb_xls', 'view_object_description', 'VIEW', NULL, 'savetodb_dev.object_translation', 'savetodb_dev.object_translation', 'savetodb_dev.object_translation', 'TABLE');
insert into `savetodb_dev`.`query_list` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_TYPE`, `TABLE_CODE`, `INSERT_PROCEDURE`, `UPDATE_PROCEDURE`, `DELETE_PROCEDURE`, `PROCEDURE_TYPE`) values ('savetodb_xls', 'view_object_translation', 'VIEW', NULL, 'savetodb_dev.object_translation', 'savetodb_dev.object_translation', 'savetodb_dev.object_translation', 'TABLE');
insert into `savetodb_dev`.`query_list` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_TYPE`, `TABLE_CODE`, `INSERT_PROCEDURE`, `UPDATE_PROCEDURE`, `DELETE_PROCEDURE`, `PROCEDURE_TYPE`) values ('savetodb_xls', 'view_column_translation', 'VIEW', NULL, 'savetodb_dev.column_translation', 'savetodb_dev.column_translation', 'savetodb_dev.column_translation', 'TABLE');

insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_dev','column_translation',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-translation.htm',NULL,11,NULL);
insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_dev','object_translation',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-translation.htm',NULL,11,NULL);
insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_dev','event_handlers',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-event-handlers.htm',NULL,11,NULL);
insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_dev','parameter_values',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-parameter-values.htm',NULL,11,NULL);
insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_dev','query_list',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-query-list.htm',NULL,11,NULL);
insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_dev','table_formats',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-table-formats.htm',NULL,11,NULL);
insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_xls','view_column_translation',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-translation.htm',NULL,11,NULL);
insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_xls','view_object_translation',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-translation.htm',NULL,11,NULL);
insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_xls','view_event_handlers',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-event-handlers.htm',NULL,11,NULL);
insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_xls','view_parameter_values',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-parameter-values.htm',NULL,11,NULL);
insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_dev','view_query_list',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-query-list.htm',NULL,11,NULL);
insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_xls','view_query_list',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-query-list.htm',NULL,11,NULL);
insert into `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`, `TARGET_WORKSHEET`, `MENU_ORDER`, `EDIT_PARAMETERS`) VALUES ('savetodb_xls','view_table_formats',NULL,'Actions','HTTP','Online Help','HTTP','http://www.savetodb.com/savetodb/configuring-table-formats.htm',NULL,11,NULL);

INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_dev', 'query_list', 'TABLE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_dev', 'query_list', 'PROCEDURE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,PROCEDURE,CODE,MERGE');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_dev', 'event_handlers', 'EVENT_NAME', 'ValidationList', NULL, '', 'VALUES', 'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_dev', 'event_handlers', 'HANDLER_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_dev', 'parameter_values', 'SELECT_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_xls', 'view_query_list', 'TABLE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_xls', 'view_query_list', 'PROCEDURE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,PROCEDURE,CODE,MERGE');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_xls', 'view_event_handlers', 'EVENT_NAME', 'ValidationList', NULL, '', 'VALUES', 'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_xls', 'view_event_handlers', 'HANDLER_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_xls', 'view_parameter_values', 'SELECT_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE');
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_dev', 'event_handlers', 'HANDLER_CODE', 'DoNotConvertFormulas', NULL, '', NULL, NULL);
INSERT INTO `savetodb_dev`.`event_handlers` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `EVENT_NAME`, `HANDLER_SCHEMA`, `HANDLER_NAME`, `HANDLER_TYPE`, `HANDLER_CODE`) VALUES ('savetodb_xls', 'view_event_handlers', 'HANDLER_CODE', 'DoNotConvertFormulas', NULL, '', NULL, NULL);

insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_dev', 'column_translation', 'en', NULL, 'Configuration Table of Column Translation', 'The table defines translation for Excel table headers and ribbon fields');
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_dev', 'event_handlers', 'en', NULL, 'Configuration Table of Excel Event Handlers', 'The table defines Excel event handlers and Actions and Context Menu items');
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_dev', 'object_translation', 'en', NULL, 'Configuration Table of Object Translation', 'The table defines translation for Query List, Actions and Context Menu items');
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_dev', 'parameter_values', 'en', NULL, 'Configuration Table of Parameter Value Queries', 'The table defines objects to select ribbon parameter values');
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_dev', 'query_list', 'en', NULL, 'Configuration Table of Query List', 'The table defines configuration of Query List objects');
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_dev', 'table_format_save', 'en', NULL, 'Configuration Procedure to Save Table Formats', 'The procedure is used to save Excel formats of database objects');
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_dev', 'table_formats', 'en', NULL, 'Configuration Table of Excel Table Formats', 'The table contains Excel formats of database objects');
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_xls', 'view_column_translation', 'en', NULL, 'Configuration View of Column Translation', NULL);
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_xls', 'view_event_handlers', 'en', NULL, 'Configuration View of Excel Event Handlers', NULL);
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_xls', 'view_object_description', 'en', 'Object Descriptions', 'Database Object Descriptions', 'You may use Query List to connect to these objects');
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_xls', 'view_object_translation', 'en', NULL, 'Configuration View of Object Translation', NULL);
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_xls', 'view_parameter_values', 'en', NULL, 'Configuration View of Parameter Value Queries', NULL);
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_xls', 'view_query_list', 'en', 'Framework Query List', 'Configuration View of Query List', NULL);
insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) values ('savetodb_xls', 'view_table_formats', 'en', NULL, 'Configuration View of Excel Table Formats', NULL);

insert into `savetodb_dev`.`object_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`, `TRANSLATED_COMMENT`) VALUES (N'HTTP', N'Online Help', N'en', N'Online Help', NULL, NULL);

insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'query_list', 'ID', 'en', NULL, NULL);
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'query_list', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'query_list', 'TABLE_NAME', 'en', NULL, 'Database object name or unique name for SQL-code and http-query');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'query_list', 'TABLE_TYPE', 'en', NULL, 'Database object type, CODE for SQL-code, or HTTP for http-query');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'query_list', 'INSERT_PROCEDURE', 'en', NULL, 'Insert procedure or destination table to save changes of views, procedures, or SQL-codes');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'query_list', 'UPDATE_PROCEDURE', 'en', NULL, 'Update procedure or destination table to save changes of views, procedures, or SQL-codes');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'query_list', 'DELETE_PROCEDURE', 'en', NULL, 'Delete procedure or destination table to save changes of views, procedures, or SQL-codes');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'event_handlers', 'ID', 'en', NULL, NULL);
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'event_handlers', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'event_handlers', 'TABLE_NAME', 'en', NULL, 'Database object name, SQL-code name, or http-query name');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'event_handlers', 'COLUMN_NAME', 'en', NULL, 'Column name or NULL to use the handler for entire table');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'event_handlers', 'EVENT_NAME', 'en', NULL, 'Actions, Change, ContextMenu, DoubleClick, or SelectionChange');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'event_handlers', 'HANDLER_SCHEMA', 'en', NULL, 'Database object schema');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'event_handlers', 'HANDLER_NAME', 'en', NULL, 'Database object name, unique name for SQL-code and http-query, or MenuSeparator');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'event_handlers', 'HANDLER_TYPE', 'en', NULL, 'Database object type, CODE for SQL-code, HTTP for http-query, or NULL for MenuSeparator');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'event_handlers', 'TARGET_WORKSHEET', 'en', NULL, 'NULL, sheet name, _new, _self, _reload. Additions: _RightWindow, _LeftWindow, _TopWindow, _BottomWindow');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'event_handlers', 'MENU_ORDER', 'en', NULL, 'Sort order of Actions and Context Menu items');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'event_handlers', 'EDIT_PARAMETERS', 'en', NULL, 'Show the Edit Parameters dialog box for Actions and Context Menu items: True/False/NULL (default behavior)');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'parameter_values', 'ID', 'en', NULL, NULL);
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'parameter_values', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'parameter_values', 'TABLE_NAME', 'en', NULL, 'Database object name');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'parameter_values', 'PARAMETER_NAME', 'en', NULL, 'Column or parameter name');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'parameter_values', 'SELECT_SCHEMA', 'en', NULL, 'Database object schema');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'parameter_values', 'SELECT_NAME', 'en', NULL, 'Database object name or name for SQL-code');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'parameter_values', 'SELECT_TYPE', 'en', NULL, 'Database object type or CODE for SQL-code');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'object_translation', 'ID', 'en', NULL, NULL);
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'object_translation', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'object_translation', 'TABLE_NAME', 'en', NULL, 'Database object name or a name of SQL-code or http-query specified in Query List and Event Handlers');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'object_translation', 'LANGUAGE_NAME', 'en', NULL, 'Two-char language code');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'object_translation', 'TRANSLATED_NAME', 'en', NULL, 'Translated name for Query List, Actions and Context Menus');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'object_translation', 'TRANSLATED_DESC', 'en', NULL, 'Text for ScreenTips and SaveToDB_Desc named cells');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'object_translation', 'TRANSLATED_COMMENT', 'en', NULL, 'Text for SuperTips and SaveToDB_Comment named cells');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'column_translation', 'ID', 'en', NULL, NULL);
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'column_translation', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema or NULL for entire database scope');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'column_translation', 'TABLE_NAME', 'en', NULL, 'Database object name or NULL for entire schema scope');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'column_translation', 'COLUMN_NAME', 'en', NULL, 'Column or parameter name');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'column_translation', 'LANGUAGE_NAME', 'en', NULL, 'Two-char language code');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'column_translation', 'TRANSLATED_NAME', 'en', NULL, 'Translated name for Excel table headers and ribbon parameters');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_dev', 'column_translation', 'TRANSLATED_DESC', 'en', NULL, 'Text for Excel table header comments and ribbon parameter SuperTips');

insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_query_list', 'ID', 'en', NULL, NULL);
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_query_list', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_query_list', 'TABLE_NAME', 'en', NULL, 'Database object name or unique name for SQL-code and http-query');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_query_list', 'TABLE_TYPE', 'en', NULL, 'Database object type, CODE for SQL-code, or HTTP for http-query');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_query_list', 'INSERT_PROCEDURE', 'en', NULL, 'Insert procedure or destination table to save changes of views, procedures, or SQL-codes');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_query_list', 'UPDATE_PROCEDURE', 'en', NULL, 'Update procedure or destination table to save changes of views, procedures, or SQL-codes');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_query_list', 'DELETE_PROCEDURE', 'en', NULL, 'Delete procedure or destination table to save changes of views, procedures, or SQL-codes');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_event_handlers', 'ID', 'en', NULL, NULL);
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_event_handlers', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_event_handlers', 'TABLE_NAME', 'en', NULL, 'Database object name, SQL-code name, or http-query name');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_event_handlers', 'COLUMN_NAME', 'en', NULL, 'Column name or NULL to use the handler for entire table');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_event_handlers', 'EVENT_NAME', 'en', NULL, 'Actions, Change, ContextMenu, DoubleClick, or SelectionChange');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_event_handlers', 'HANDLER_SCHEMA', 'en', NULL, 'Database object schema');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_event_handlers', 'HANDLER_NAME', 'en', NULL, 'Database object name, unique name for SQL-code and http-query, or MenuSeparator');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_event_handlers', 'HANDLER_TYPE', 'en', NULL, 'Database object type, CODE for SQL-code, HTTP for http-query, or NULL for MenuSeparator');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_event_handlers', 'TARGET_WORKSHEET', 'en', NULL, 'NULL, sheet name, _new, _self, _reload. Additions: _RightWindow, _LeftWindow, _TopWindow, _BottomWindow');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_event_handlers', 'MENU_ORDER', 'en', NULL, 'Sort order of Actions and Context Menu items');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_event_handlers', 'EDIT_PARAMETERS', 'en', NULL, 'Show the Edit Parameters dialog box for Actions and Context Menu items: True/False/NULL (default behavior)');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_parameter_values', 'ID', 'en', NULL, NULL);
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_parameter_values', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_parameter_values', 'TABLE_NAME', 'en', NULL, 'Database object name');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_parameter_values', 'PARAMETER_NAME', 'en', NULL, 'Column or parameter name');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_parameter_values', 'SELECT_SCHEMA', 'en', NULL, 'Database object schema');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_parameter_values', 'SELECT_NAME', 'en', NULL, 'Database object name or name for SQL-code');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_parameter_values', 'SELECT_TYPE', 'en', NULL, 'Database object type or CODE for SQL-code');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_object_translation', 'ID', 'en', NULL, NULL);
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_object_translation', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_object_translation', 'TABLE_NAME', 'en', NULL, 'Database object name or a name of SQL-code or http-query specified in Query List and Event Handlers');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_object_translation', 'LANGUAGE_NAME', 'en', NULL, 'Two-char language code');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_object_translation', 'TRANSLATED_NAME', 'en', NULL, 'Translated name for Query List, Actions and Context Menus');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_object_translation', 'TRANSLATED_DESC', 'en', NULL, 'Text for ScreenTips and SaveToDB_Desc named cells');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_object_translation', 'TRANSLATED_COMMENT', 'en', NULL, 'Text for SuperTips and SaveToDB_Comment named cells');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_column_translation', 'ID', 'en', NULL, NULL);
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_column_translation', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema or NULL for entire database scope');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_column_translation', 'TABLE_NAME', 'en', NULL, 'Database object name or NULL for entire schema scope');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_column_translation', 'COLUMN_NAME', 'en', NULL, 'Column or parameter name');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_column_translation', 'LANGUAGE_NAME', 'en', NULL, 'Two-char language code');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_column_translation', 'TRANSLATED_NAME', 'en', NULL, 'Translated name for Excel table headers and ribbon parameters');
insert into `savetodb_dev`.`column_translation` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `LANGUAGE_NAME`, `TRANSLATED_NAME`, `TRANSLATED_DESC`) values ('savetodb_xls', 'view_column_translation', 'TRANSLATED_DESC', 'en', NULL, 'Text for Excel table header comments and ribbon parameter SuperTips');

insert into `savetodb_dev`.`table_formats` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_EXCEL_FORMAT_XML`) values ('savetodb_xls', 'view_object_description', '<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_xls.view_object_description">
<columnFormats>
<column name="" property="ListObjectName" value="UserObjects_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LANGUAGE_NAME" property="Address" value="$C$7" type="String" />
<column name="LANGUAGE_NAME" property="ColumnWidth" value="0.08" type="Double" />
<column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_NAME" property="Address" value="$F$7" type="String" />
<column name="TRANSLATED_NAME" property="ColumnWidth" value="24" type="Double" />
<column name="TRANSLATED_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_COMMENT" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Address" value="$G$7" type="String" />
<column name="TRANSLATED_COMMENT" property="ColumnWidth" value="108.86" type="Double" />
<column name="TRANSLATED_COMMENT" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_COMMENT" property="WrapText" value="True" type="Boolean" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="False" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="False" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="-6" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>');
insert into `savetodb_dev`.`table_formats` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_EXCEL_FORMAT_XML`) values ('savetodb_dev', 'query_list', '<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.query_list">
<columnFormats>
<column name="" property="ListObjectName" value="QueryList_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="23.29" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_TYPE" property="Address" value="$F$7" type="String" />
<column name="TABLE_TYPE" property="ColumnWidth" value="13.14" type="Double" />
<column name="TABLE_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="TABLE_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_TYPE" property="Validation.Operator" value="1" type="Double" />
<column name="TABLE_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;CODE;HTTP;TEXT" type="String" />
<column name="TABLE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_CODE" property="Address" value="$G$7" type="String" />
<column name="TABLE_CODE" property="ColumnWidth" value="13.57" type="Double" />
<column name="INSERT_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="INSERT_PROCEDURE" property="Address" value="$H$7" type="String" />
<column name="INSERT_PROCEDURE" property="ColumnWidth" value="31.14" type="Double" />
<column name="INSERT_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="UPDATE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="UPDATE_PROCEDURE" property="Address" value="$I$7" type="String" />
<column name="UPDATE_PROCEDURE" property="ColumnWidth" value="31.14" type="Double" />
<column name="UPDATE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="DELETE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DELETE_PROCEDURE" property="Address" value="$J$7" type="String" />
<column name="DELETE_PROCEDURE" property="ColumnWidth" value="31.14" type="Double" />
<column name="DELETE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="PROCEDURE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Address" value="$K$7" type="String" />
<column name="PROCEDURE_TYPE" property="ColumnWidth" value="18.43" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Operator" value="1" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Formula1" value="TABLE;PROCEDURE;CODE;MERGE" type="String" />
<column name="PROCEDURE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
insert into `savetodb_dev`.`table_formats` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_EXCEL_FORMAT_XML`) values ('savetodb_dev', 'event_handlers', '<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.event_handlers">
<columnFormats>
<column name="" property="ListObjectName" value="EventHandlers_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="18.57" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="COLUMN_NAME" property="Address" value="$F$7" type="String" />
<column name="COLUMN_NAME" property="ColumnWidth" value="17.43" type="Double" />
<column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double" />
<column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="COLUMN_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EVENT_NAME" property="Address" value="$G$7" type="String" />
<column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double" />
<column name="EVENT_NAME" property="Validation.Type" value="3" type="Double" />
<column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;ConvertFormulas;DoNotConvertFormulas;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String" />
<column name="EVENT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String" />
<column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double" />
<column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_NAME" property="Address" value="$I$7" type="String" />
<column name="HANDLER_NAME" property="ColumnWidth" value="26.14" type="Double" />
<column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_NAME" property="Validation.Formula1" value="2000" type="String" />
<column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_TYPE" property="Address" value="$J$7" type="String" />
<column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Operator" value="1" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;VALUES;RANGE;REFRESH;MENUSEPARATOR" type="String" />
<column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_CODE" property="Address" value="$K$7" type="String" />
<column name="HANDLER_CODE" property="ColumnWidth" value="42.14" type="Double" />
<column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String" />
<column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Formula1" value="64" type="String" />
<column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean" />
<column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="MENU_ORDER" property="Address" value="$M$7" type="String" />
<column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double" />
<column name="MENU_ORDER" property="Validation.Type" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Formula1" value="-32768" type="String" />
<column name="MENU_ORDER" property="Validation.Formula2" value="32767" type="String" />
<column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String" />
<column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Type" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Operator" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Formula1" value="-32768" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.Formula2" value="32767" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$12" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
insert into `savetodb_dev`.`table_formats` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_EXCEL_FORMAT_XML`) values ('savetodb_dev', 'parameter_values', '<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.parameter_values">
<columnFormats>
<column name="" property="ListObjectName" value="ParameterValues_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="18.57" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PARAMETER_NAME" property="Address" value="$F$7" type="String" />
<column name="PARAMETER_NAME" property="ColumnWidth" value="20.29" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="PARAMETER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="PARAMETER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_SCHEMA" property="Address" value="$G$7" type="String" />
<column name="SELECT_SCHEMA" property="ColumnWidth" value="17.29" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Formula1" value="64" type="String" />
<column name="SELECT_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_NAME" property="Address" value="$H$7" type="String" />
<column name="SELECT_NAME" property="ColumnWidth" value="15.29" type="Double" />
<column name="SELECT_NAME" property="Validation.Type" value="6" type="Double" />
<column name="SELECT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="SELECT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_TYPE" property="Address" value="$I$7" type="String" />
<column name="SELECT_TYPE" property="ColumnWidth" value="13.86" type="Double" />
<column name="SELECT_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="SELECT_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;VALUES;RANGE" type="String" />
<column name="SELECT_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_CODE" property="Address" value="$J$7" type="String" />
<column name="SELECT_CODE" property="ColumnWidth" value="53" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$8" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$8" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$F$8" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$8" type="String" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).AppliesTo.Address" value="$H$7:$H$8" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Priority" value="5" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(H7)" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).AppliesTo.Address" value="$I$7:$I$8" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Priority" value="6" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Formula1" value="=ISBLANK(I7)" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
insert into `savetodb_dev`.`table_formats` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_EXCEL_FORMAT_XML`) values ('savetodb_dev', 'object_translation', '<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.object_translation">
<columnFormats>
<column name="" property="ListObjectName" value="ObjectTranslation_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="26.14" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LANGUAGE_NAME" property="Address" value="$F$7" type="String" />
<column name="LANGUAGE_NAME" property="ColumnWidth" value="3.57" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Formula1" value="2" type="String" />
<column name="LANGUAGE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_NAME" property="Address" value="$G$7" type="String" />
<column name="TRANSLATED_NAME" property="ColumnWidth" value="23.71" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="TRANSLATED_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_DESC" property="Address" value="$H$7" type="String" />
<column name="TRANSLATED_DESC" property="ColumnWidth" value="19.57" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Formula1" value="256" type="String" />
<column name="TRANSLATED_DESC" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Address" value="$I$7" type="String" />
<column name="TRANSLATED_COMMENT" property="ColumnWidth" value="25" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.Formula1" value="2000" type="String" />
<column name="TRANSLATED_COMMENT" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).ColumnsCount" value="3" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$F$9" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="LANGUAGE_NAME" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="TABLE_SCHEMA" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="SortFields(3)" property="KeyfieldName" value="TABLE_NAME" type="String" />
<column name="SortFields(3)" property="SortOn" value="0" type="Double" />
<column name="SortFields(3)" property="Order" value="1" type="Double" />
<column name="SortFields(3)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
insert into `savetodb_dev`.`table_formats` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_EXCEL_FORMAT_XML`) values ('savetodb_dev', 'column_translation', '<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.column_translation">
<columnFormats>
<column name="" property="ListObjectName" value="ColumnTranslation_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="23.14" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="COLUMN_NAME" property="Address" value="$F$7" type="String" />
<column name="COLUMN_NAME" property="ColumnWidth" value="22.43" type="Double" />
<column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double" />
<column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="COLUMN_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LANGUAGE_NAME" property="Address" value="$G$7" type="String" />
<column name="LANGUAGE_NAME" property="ColumnWidth" value="4.57" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Formula1" value="2" type="String" />
<column name="LANGUAGE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_NAME" property="Address" value="$H$7" type="String" />
<column name="TRANSLATED_NAME" property="ColumnWidth" value="20.71" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="TRANSLATED_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_DESC" property="Address" value="$I$7" type="String" />
<column name="TRANSLATED_DESC" property="ColumnWidth" value="19.57" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Formula1" value="1024" type="String" />
<column name="TRANSLATED_DESC" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="FormatConditions(1).ColumnsCount" value="2" type="Double" />
<column name="COLUMN_NAME" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$G$16" type="String" />
<column name="COLUMN_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="COLUMN_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="COLUMN_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="COLUMN_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="COLUMN_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
insert into `savetodb_dev`.`table_formats` (`TABLE_SCHEMA`, `TABLE_NAME`, `TABLE_EXCEL_FORMAT_XML`) values ('savetodb_dev', 'table_formats', '<?xml version="1.0" encoding="Unicode"?>
<table name="savetodb_dev.table_formats">
<columnFormats>
<column name="" property="ListObjectName" value="UserObjects_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="22.57" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="64" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_EXCEL_FORMAT_XML" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_EXCEL_FORMAT_XML" property="Address" value="$F$7" type="String" />
<column name="TABLE_EXCEL_FORMAT_XML" property="ColumnWidth" value="70.71" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$13" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).ColumnsCount" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$E$13" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="4" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$13" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="False" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="False" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="-6" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>');

-- print SaveToDB Framework data have been added

-- print SaveToDB Framework has been installed
